==> gd32f1-0.2.0.crate: gd32f1-0.2.0/src/gd32f190/dac/dac1_do.rs <==
#[doc = "Register `DAC1_DO` reader"]
pub struct R(crate::R<DAC1_DO_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DAC1_DO_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<DAC1_DO_SPEC>> for R {
    fn from(reader: crate::R<DAC1_DO_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `DAC1_DO` reader - DAC1 output data"]
pub struct DAC1_DO_R(crate::FieldReader<u16, u16>);
impl DAC1_DO_R {
    pub(crate) fn new(bits: u16) -> Self {
        DAC1_DO_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DAC1_DO_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:11 - DAC1 output data"]
    #[inline(always)]
    pub fn dac1_do(&self) -> DAC1_DO_R {
        DAC1_DO_R::new((self.bits & 0x0fff) as u16)
    }
}
#[doc = "DAC1 data output register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dac1_do](index.html) module"]
pub struct DAC1_DO_SPEC;
impl crate::RegisterSpec for DAC1_DO_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dac1_do::R](R) reader structure"]
impl crate::Readable for DAC1_DO_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets DAC1_DO to value 0"]
impl crate::Resettable for DAC1_DO_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f190/dac/dac1_do.rs <==
#[doc = "Register `DAC1_DO` reader"]
pub struct R(crate::R<DAC1_DO_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DAC1_DO_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DAC1_DO_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DAC1_DO_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `DAC1_DO` reader - DAC1 output data"]
pub struct DAC1_DO_R(crate::FieldReader<u16, u16>);
impl DAC1_DO_R {
    pub(crate) fn new(bits: u16) -> Self {
        DAC1_DO_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DAC1_DO_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:11 - DAC1 output data"]
    #[inline(always)]
    pub fn dac1_do(&self) -> DAC1_DO_R {
        DAC1_DO_R::new((self.bits & 0x0fff) as u16)
    }
}
#[doc = "DAC1 data output register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dac1_do](index.html) module"]
pub struct DAC1_DO_SPEC;
impl crate::RegisterSpec for DAC1_DO_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dac1_do::R](R) reader structure"]
impl crate::Readable for DAC1_DO_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets DAC1_DO to value 0"]
impl crate::Resettable for DAC1_DO_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
